File

Struct File 

pub struct File {
    pub version: String,
    pub services: BTreeMap<String, Service>,
    pub volumes: BTreeMap<String, Volume>,
    pub networks: BTreeMap<String, Network>,
    /* private fields */
}
A docker-compose.yml file.

Fields

version: String

The version of the docker-compose.yml file format. Must be 2.

services: BTreeMap<String, Service>

The individual services which make up this app.

volumes: BTreeMap<String, Volume>

Named volumes used by this app.

TODO MED: Can we parse just volume names followed by a colon?

networks: BTreeMap<String, Network>

The networks used by this app.

Implementations

Source

impl File

pub fn read<R>(r: R) -> Result<Self>
where R: Read,

Read a file from an input stream containing YAML.

pub fn write<W>(&self, w: &mut W) -> Result<()>
where W: Write,

Write a file to an output stream as YAML.

pub fn read_from_path<P>(path: P) -> Result<Self>
where P: AsRef<Path>,

Read a file from the specified path.

pub fn write_to_path<P>(&self, path: P) -> Result<()>
where P: AsRef<Path>,

Write a file to the specified path.

pub fn inline_all(&mut self, base: &Path) -> Result<()>

Inline all our external resources, such as env_files, looking up paths relative to base.

pub fn make_standalone(&mut self, base: &Path) -> Result<()>

Convert this file to a standalone file, with no dependencies on the current environment or any external files. This does not lock down the image versions used in this file.